summaryrefslogtreecommitdiff
path: root/sw/source/core/inc/scriptinfo.hxx
diff options
context:
space:
mode:
authorMatteo Casalin <matteo.casalin@yahoo.com>2014-08-31 17:43:26 +0200
committerMatteo Casalin <matteo.casalin@yahoo.com>2014-09-06 12:12:27 +0200
commitbc3b71a93edd2ee57b6b01f41094705bcb6b3830 (patch)
tree0cec602f6011cedee79c4bc902fb90a526e9de60 /sw/source/core/inc/scriptinfo.hxx
parente24a3daf040410bd9fb2eb6cdd7095a659427441 (diff)
sal_uInt16 to more proper types, constify
Change-Id: I2924f1f8c6ac0e82340293f92656541ffecbcf24
Diffstat (limited to 'sw/source/core/inc/scriptinfo.hxx')
-rw-r--r--sw/source/core/inc/scriptinfo.hxx4
1 files changed, 2 insertions, 2 deletions
diff --git a/sw/source/core/inc/scriptinfo.hxx b/sw/source/core/inc/scriptinfo.hxx
index 6ed350960d19..b7734fbb0dd2 100644
--- a/sw/source/core/inc/scriptinfo.hxx
+++ b/sw/source/core/inc/scriptinfo.hxx
@@ -247,8 +247,8 @@ public:
// HIDDEN TEXT STUFF END
// examines the range [ nStart, nStart + nEnd ] if there are kanas
- // returns start index of kana entry in array, otherwise USHRT_MAX
- sal_uInt16 HasKana( sal_Int32 nStart, const sal_Int32 nEnd ) const;
+ // returns start index of kana entry in array, otherwise SAL_MAX_SIZE
+ size_t HasKana( sal_Int32 nStart, const sal_Int32 nEnd ) const;
// modifies the kerning array according to a given compress value
long Compress( long* pKernArray, sal_Int32 nIdx, sal_Int32 nLen,